/*
 * intf.h - interface monitor
 *
 * Copyright (C) 2002 Thomas Graf <tgr@kaosu.ch>
 */

#ifndef INTF_H_
#define INTF_H_

#include "bmon.h"

#define MAX_IF 255                              /* max configured interfaces */
#define IFNAME_MAX 26                           /* max interface name length */

typedef uint64_t intf_cnt_t;

typedef struct rate_s
{
    intf_cnt_t      cnt;
    intf_cnt_t      cnt_before;
    unsigned int    rate;

    struct timeval  last_calculation;

} rate_t;
    

typedef struct intf_s
{
    char          name[IFNAME_MAX];            /* interface name */

    rate_t        rx_bytes;
    rate_t        tx_bytes;

    rate_t        rx_packets;
    rate_t        tx_packets;

    intf_cnt_t    rx_errors;
    intf_cnt_t    rx_drop;
    intf_cnt_t    rx_fifo;
    intf_cnt_t    rx_frame;
    intf_cnt_t    rx_compressed;      
    intf_cnt_t    rx_multicast;       
    intf_cnt_t    rx_broadcast;

    intf_cnt_t    tx_errors;
    intf_cnt_t    tx_drop;
    intf_cnt_t    tx_fifo;
    intf_cnt_t    tx_frame;
    intf_cnt_t    tx_compressed;
    intf_cnt_t    tx_multicast;
    intf_cnt_t    tx_broadcast;

    struct timeval read_ts;

    struct intf_table_s
    {
        intf_cnt_t              rx_rate[60];
        intf_cnt_t              tx_rate[60];

        intf_cnt_t              rx_cnt_before;
        intf_cnt_t              tx_cnt_before;

        unsigned char           rx_graph[6][61];
        unsigned char           tx_graph[6][61];

        int                     index;

        unsigned int            rx_scale[6];
        unsigned int            tx_scale[6];

        struct timeval          last_calculation;

    } s, m, h;

    int already_updated:1;
    int to_remove:1;                 /* flag to mark interfaces as to remove */

} intf_t;


/*
 * reads /proc/net/dev and updates each interface entry. must be called
 * frequently like every second
 */
void intf_readfile(const char *path);

void intf_read_netstat(const char *netstat_cmd);

#if defined HAVE_KSTAT && defined SYS_SUNOS
void intf_read_kstat(void);
#endif

#if defined SYS_BSD
void intf_read_sysctl(void);
#endif

void intf_calc_all(void);

/*
 * helper function
 */
float p_diff_now (struct timeval *t1);


#endif
